@@ -7,6 +7,7 @@ Wisdom is the user interaction with Whatify wisdom, it contains
 #
 # ‘Prediction’ API includes querying of predictions (Get, List and Delete) and creating a Prediction to get predictions
 # on existing Ensembles and uploaded Datasources.
+import logging
 import os
 
 import s3fs
@@ -58,11 +59,16 @@ class UserManagement(APIResource):
         Returns:
             WhatifyResponse: Empty WhatifyResponse if successful, raises FireflyError otherwise.
         """
+        logging.info(' '.join(['login with user:', str(email)]))
         url = 'login'
         requestor = APIRequestor()
-        response = requestor.post(url, body={'username': email, 'password': password, 'tnc': None}, api_key="")
-        toolkit_w.token = response['token']
-        print(' '.join(['user mail:', str(email), '- Login successful']))
+        try:
+            response = requestor.post(url, body={'username': email, 'password': password, 'tnc': None}, api_key="")
+            toolkit_w.token = response['token']
+            logging.info(' '.join(['user mail:', str(email), '- Login successful']))
+        except Exception as ex:
+            logging.warning(' '.join(['user mail:', str(email), '- Login FAILED']))
+            raise ex
 
         return WhatifyResponse(status_code=response.status_code, headers=response.headers)
 
@@ -79,14 +85,15 @@ class UserManagement(APIResource):
        Returns:
            WhatifyResponse: Empty WhatifyResponse if successful, raises WhatifyError otherwise.
        """
+        logging.info(' '.join(['impersonate to user_ID:', str(user_id)]))
         url = ''.join(['users/login_as/', str(user_id)])
         requester = APIRequestor()
         try:
             response = requester.post(url, api_key=admin_token)
             toolkit_w.token = response['result']
-            print(' '.join(['user ID:', str(user_id), '- Login successful']))
+            logging.info(' '.join(['user ID:', str(user_id), '- Login successful']))
         except Exception as ex:
-            print(' '.join(['user ID:', str(user_id), '- Login Failed']))
+            logging.warning(' '.join(['user ID:', str(user_id), '- Login Failed']))
             raise ex
 
         return WhatifyResponse(status_code=response.status_code, headers=response.headers)
